/**
 * Copyright (c) 2007-2012 EBM WebSourcing, 2012-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.bc.mail;

import javax.xml.namespace.QName;

/**
 * @author Adrien LOUIS - EBM WebSourcing
 * @author Christophe HAMERLING - EBM WebSourcing
 * @author Mathieu CARROLLE - EBM WebSourcing
 */
public interface MailConstants {

    public static final String BODY_PATHELEMENT = "body";

    public static final String CONTENTTYPE_PATHELEMENT = "content-type";

    // If true in CONSUMES mode, assume default mail content is XML
    public static final String IS_XML_CONTENT = "isxmlcontent";

    public static final String EXPUNGE_PATHELEMENT = "delete";

    public static final String FOLDER_DEFAULT = "INBOX";

    public static final String FOLDER_QUERYELEMENT = "folder";

    public static final String FROM_PATHELEMENT = "from";
    
    public static final String SCHEME_PATHELEMENT = "scheme";

    public static final String MAIL_FROM_KEY = "mail.from";

    public static final String MAIL_HOST_KEY = "mail.host";

    public static final String MAIL_IMAP_PORT_DEFAULT = "143";

    public static final String MAIL_POP3_PORT_DEFAULT = "110";

    public static final String MAIL_SCHEME_IMAP = "imap";

    public static final String MAIL_SCHEME_POP3 = "pop3";

    public static final String MAIL_SCHEME_SMTP = "smtp";

    public static final String MAIL_STORE_PROTOCOL_KEY = "mail.store.protocol";

    public static final String MAIL_TRANSPORT_PROTOCOL_KEY = "mail.transport.protocol";

    public static final String HELO_HOST_PATHELEMENT = "helohost";

    public static final String MAIL_HELO_HOST = "mail.smtp.localhost";

    public static final String MAIL_USER_KEY = "mail.user";

    public static final String PERIOD_DEFAULT = "60000";

    public static final String PERIOD_QUERYELEMENT = "period";

    public static final String QUERY_SEPARATOR = "&";

    public static final String REPLY_PATHELEMENT = "reply";

    public static final String MAIL_SERVICE_NS = "http://petals.ow2.org/components/mail/version-3";

    public static final QName SEND_MAIL_OPERATION = new QName(MAIL_SERVICE_NS, "SendMail");

    public static final String SUBJECT_PATHELEMENT = "subject";

    public static final String TO_PATHELEMENT = "to";

    public static final String HOST_PATHELEMENT = "host";

    public static final String USER_PATHELEMENT = "user";

    public static final String PASSWORD_PATHELEMENT = "password";

    public static final String PORT_PATHELEMENT = "port";

    // Send mode
    public static final String SEND_MODE_PATHELEMENT = "send-mode";

    public static final String SEND_MODE_CONTENTONLY = "content-only";

    public static final String SEND_MODE_ATTACHMENTSONLY = "attachments-only";

    public static final String SEND_MODE_CONTENTATTACHMENTS = "content-and-attachments";

    public static final String MAIL_INTEGRATION_SERVICE_NS = "http://petals.ow2.org/components/mail/generic/version-3";

    /**
     * WS-addressing Constants extensions
     * 
     * Note: we use the ws-addressing namespace for some of the properties with no specific reasons.
     * 
     */
    public static class MailWSAddressing {

        public static final String WSA_NAMESPACE_URI = "http://www.w3.org/2005/08/addressing";

        public static final String WSA_PREFIX = "wsa";

        public static final QName REPLY_TO_QNAME = new QName(WSA_NAMESPACE_URI, "ReplyTo", WSA_PREFIX);

        public static final QName FROM_QNAME = new QName(WSA_NAMESPACE_URI, "From", WSA_PREFIX);

        public static final QName TO_QNAME = new QName(WSA_NAMESPACE_URI, "To", WSA_PREFIX);

        public static final QName ACTION_QNAME = new QName(WSA_NAMESPACE_URI, "Action", WSA_PREFIX);

        public static final QName HOST_QNAME = new QName(MAIL_SERVICE_NS, "Host");

        public static final QName PORT_QNAME = new QName(MAIL_SERVICE_NS, "Port");

        public static final QName USER_QNAME = new QName(MAIL_SERVICE_NS, "Username");

        public static final QName PASSWORD_QNAME = new QName(MAIL_SERVICE_NS, "Password");

        public static final QName SENDMODE_QNAME = new QName(MAIL_SERVICE_NS, "SendMode");

        public static final QName CONTENTTYPE_QNAME = new QName(MAIL_SERVICE_NS, "ContentType");

        public static final QName HELOHOST_QNAME = new QName(MAIL_SERVICE_NS, "HeloHost");

        public static final QName SCHEME_QNAME = new QName(MAIL_SERVICE_NS, "Scheme");
    }
}
