/**
 * Copyright (c) 2006-2012 EBM WebSourcing, 2012-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.bc.mail.service.provide;

import org.ow2.petals.bc.mail.MailConstants;

import com.ebmwebsourcing.easycommons.lang.StringHelper;

/**
 * This descriptor handles information used to connect to a mail server to read or send emails.
 * @author Adrien LOUIS - EBM WebSourcing
 * @author Olivier Fabre - EBM WebSourcing
 */
public class ProvideDescriptor {

    /**
     * The default value of the SMTP port
     */
    public static final String MAIL_SMTP_PORT_DEFAULT;

    static {
        // We initialize the value in a static block to be able to change the default value by reflection for unit test
        // purpose, otherwise the default value is inlined by the compiler
        MAIL_SMTP_PORT_DEFAULT = "25";
    }

    /**
     * Used for both smtp, imap and pop3 scheme
     */
    private String scheme;

    /**
     * Used for both smtp, imap and pop3 scheme
     */
    private String hostname;

    /**
     * Used for both smtp, imap and pop3 scheme
     */
    private String port;

    /**
     * Used for both smtp, imap and pop3 scheme
     */
    private String username;

    /**
     * Used for both smtp, imap and pop3 scheme
     */
    private String password;

    /**
     * Used only for smtp scheme
     */
    private String fromAddress;

    /**
     * ReplyTo
     */
    private String replyAddress;

    /**
     * Used only for smtp scheme
     */
    private String toAddress;

    /**
     * Subject
     */
    private String subject;

    /**
     * HELO host name (mail.smtp.localhost)
     */
    private String heloHost;

    /**
     * Send either the source, the attachments or both of the payload. Default
     * value is : content-and-attachments.
     */
    private String sendMode;

    /**
     * Specify the mime content-type for the created email
     */
    private String contentType;

    public String getScheme() {
        return this.scheme;
    }

    public void setScheme(final String scheme) {
        if (StringHelper.isNullOrEmpty(scheme)) {
            this.scheme = MailConstants.MAIL_SCHEME_SMTP;
        } else {
            this.scheme = scheme;
        }
    }

    public String getHostname() {
        return this.hostname;
    }

    public void setHostname(final String hostname) {
        this.hostname = hostname;
    }

    public String getPort() {
        return this.port;
    }

    public void setPort(final String port) {
        if (StringHelper.isNullOrEmpty(port)) {
            this.port = MAIL_SMTP_PORT_DEFAULT;
        } else {
            this.port = port;
        }
    }

    public String getUsername() {
        return this.username;
    }

    public void setUsername(final String username) {
        this.username = username;
    }

    public String getPassword() {
        return this.password;
    }

    public void setPassword(final String password) {
        this.password = password;
    }

    public String getFromAddress() {
        return this.fromAddress;
    }

    public void setFromAddress(final String fromAddress) {
        this.fromAddress = fromAddress;
    }

    public String getReplyAddress() {
        return this.replyAddress;
    }

    public void setReplyAddress(final String replyAddress) {
        this.replyAddress = replyAddress;
    }

    public String getToAddress() {
        return this.toAddress;
    }

    public void setToAddress(final String toAddress) {
        this.toAddress = toAddress;
    }

    public String getSubject() {
        return this.subject;
    }

    public void setSubject(final String subject) {
        this.subject = subject;
    }

    public String getHeloHost() {
        return this.heloHost;
    }

    public void setHeloHost(final String heloHost) {
        this.heloHost = heloHost;
    }

    public String getSendMode() {
        return this.sendMode;
    }

    public void setSendMode(final String sendMode) {
        if (StringHelper.isNullOrEmpty(sendMode)) {
            this.sendMode = MailConstants.SEND_MODE_CONTENTATTACHMENTS;
        } else {
            this.sendMode = sendMode;
        }
    }

    public String getContentType() {
        return this.contentType;
    }

    public void setContentType(final String contentType) {
        if (StringHelper.isNullOrEmpty(contentType)) {
            this.contentType = "text/plain";
        } else {
            this.contentType = contentType;
        }
    }
}
